==================
EZID Python Client
==================

============================
NOT AN OFFICIAL EZID PROJECT
============================

A Python client to ease programmatic use of the EZID web api.

Currently, the module also provides the same client interface as the sample
code in https://ezid.cdlib.org/doc/apidoc.html and borrows heavily from it.

See https://bitbucket.org/mredar/ezid for most current source

This is not officially endorsed by EZID. For any problems with the code, please contact me directly at mark dot redar at ucop dot edu.
